@@ -242,9 +242,19 @@ SEXP getTable(const std::shared_ptr<cpptoml::table>& t, bool verbose=false) {
                 Rcpp::Rcout << std::endl;
             }
             sl.push_back(Rcpp::Named(p.first) = getValue(p.second)); 
-            
+        } else if (p.second->is_table_array()) {
+            if (verbose) Rcpp::Rcout << "TableArray: " << p.first << std::endl;
+            Rcpp::StretchyList l;
+            auto arr = t->get_table_array(p.first)->get();
+            auto ait = arr.begin();
+            while (ait != arr.end()) {
+                auto ta = std::dynamic_pointer_cast<cpptoml::table>(*ait);
+                l.push_back (getTable(ta, verbose));
+                ++ait;
+            }
+            sl.push_back(Rcpp::Named(p.first) = l);
         } else {
-            Rcpp::Rcout << "Other: " << p.first << std::endl;
+            if (verbose) Rcpp::Rcout << "Other: " << p.first << std::endl;
             sl.push_back(p.first); 
         }
     }
